<?php

declare(strict_types=1);

namespace Drupal\Tests\kameleoon\Functional;

use Drupal\Tests\BrowserTestBase;

/**
 * Functional test for the Kameleoon settings form.
 */
class SettingsFormTest extends BrowserTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = ['kameleoon', 'key'];

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * A user with the 'administer site configuration' permission.
   *
   * @var \Drupal\user\UserInterface
   */
  protected $adminUser;

  /**
   * {@inheritdoc}
   */
  public function setUp(): void {
    parent::setUp();

    $this->adminUser = $this->drupalCreateUser([
      'administer site configuration',
      'administer keys',
    ]);

    // Log in as an administrator.
    $this->drupalLogin($this->adminUser);

    // Create a new key in in the key module.
    $this->drupalGet('admin/config/system/keys/add');
    $edit = [
      'id' => 'test_sitecode',
      'label' => 'Testing Key',
      'key_type' => 'authentication',
      'key_input_settings[key_value]' => 'key_value',
    ];
    $this->submitForm($edit, 'Save');
  }

  /**
   * Tests the settings form.
   */
  public function testSettingsForm(): void {
    // Navigate to the settings form.
    $this->drupalGet('admin/config/services/kameleoon');

    // Assert that the form is displayed.
    $this->assertSession()->statusCodeEquals(200);
    $this->assertSession()->fieldExists('sitecode');
    $this->assertSession()->fieldExists('script');
    $this->assertSession()->fieldExists('loading_timeout');

    // Submit the form with test values.
    $edit = [
      'sitecode' => 'test_sitecode',
      'script' => 'async',
      'loading_timeout' => 5000,
    ];
    $this->submitForm($edit, 'Save configuration');

    // Verify that the configuration was saved.
    $config = $this->config('kameleoon.settings');
    $this->assertEquals('test_sitecode', $config->get('sitecode'));
    $this->assertEquals('async', $config->get('script'));
    $this->assertEquals(5000, $config->get('loading_timeout'));
  }

}
